using System;
using System.IO;
using System.Net;

using Newtonsoft.Json;

namespace IdehPayam {
    public enum ServiceType { SOAP = 1, REST = 2 };

    public class UserCreditJsonResult
    {
        public int status { get; set; }
        public int value { get; set; }
    }

    public class UserCreditJsonResponse
    {
        public int status { get; set; }
        public UserCreditJsonResult result { get; set; }
    }

    class ClientApi {
        private static string _restUrl = "http://localhost:8800/idehpayam/new-api/rest.php";
        private static string _soapUrl = "http://localhost:8800/idehpayam/new-api/soap.php?wsdl";

        private string _username = "";
        private string _password = "";
        private string _lastError = "";
        private string _lastResponse = "";

        public ClientApi(string username, string passsword)
        {
            this._username = username;
            this._password = passsword;
        }

        public float GetUserCredit(ServiceType type)
        {
            switch (type) {
                case ServiceType.REST:
                    var httpWebRequest = (HttpWebRequest)WebRequest.Create(ClientApi._restUrl);
                    httpWebRequest.ContentType = "application/json";
                    httpWebRequest.Method = "POST";

                    using (var streamWriter = new StreamWriter(httpWebRequest.GetRequestStream())) {
                        string json = "{\"operation\":\"GetUserCredit\", \"username\":\"" + this._username + "\", \"password\":\"" + this._password + "\"}";
                        streamWriter.Write(json);
                    }

                    var httpResponse = (HttpWebResponse)httpWebRequest.GetResponse();
                    using (var streamReader = new StreamReader(httpResponse.GetResponseStream())) {
                        UserCreditJsonResponse response = JsonConvert.DeserializeObject<UserCreditJsonResponse>(streamReader.ReadToEnd());
                        this._lastResponse = response.ToString();
                        if (response.status == 200) {
                            if (response.result.status == 0) {
                                return response.result.value;
                            } else {
                                this._lastError = "Api status code " + response.result.status + " returned.";
                            }
                        } else {
                            this._lastError = "Status code is not OK";
                        }
                        System.Console.WriteLine(response.status);
                    }

                    return 0;
                case ServiceType.SOAP:
                    return -1;
                default:
                    throw new Exception("This service type is not valid.");
            }
        }
    }

    class MainClass {
        public static void Main (string[] args) {
            ClientApi client = new ClientApi("prodo", "123456");
            float credit = client.GetUserCredit(ServiceType.REST);
            Console.WriteLine(credit);
        }
    }
}
